@@ -3,6 +3,8 @@ from copy import deepcopy
 
 import jax
 import jax.numpy as jnp
+import jax.random as jr
+from chex import PRNGKey
 from jaxtyping import f64
 
 
